.. _interface:

*******************
Interface functions
*******************

These functions allow you to activate/deactivate provenance tracking,
and view the raw history, and serialize the information to a file.

.. autofunction:: alpaca.activate

.. autofunction:: alpaca.deactivate

.. autofunction:: alpaca.print_history

.. autofunction:: alpaca.save_provenance
